def main():
	print('''
	AON (Advanced object notation)
	------------------------------

	Description:
	-----------
		*This is similar to JSON but it was developed using python.
		*Python is having huge community and opensource so this is a base version.
	Usage:
	-----
		*It has two method make inside maker package which will convert your AON file by taking path as arg.
		*load method return the data from the AON file.
		Note: without calling make method no data available.
	Contact Details:
	---------------
	Koppula Praveen Kumar
	koppulapraveen920@gmail.com
	 ''')



import os
import shutil
import tempo

def make(path):
	n=[i for i in path.split("/")]
	empty('tempo.py')
	file=open(n[-1],'r')
	content=file.read()

	fc=open('tempo.py','w')
	fc.seek(0)
	fc.write('tempo='+content)
	fc.close()

def load():
	t=tempo.tempo
	return t

def empty(path):
	fc=open(path,'w')
	fc.write('')
	fc.close()
	



from setuptools import setup

def readme():
    with open('README.md') as f:
        README = f.read()
    return README


setup(
    name="AON",
    version="1.0.0",
    description="Advanced object notation based on python.",
    long_description=readme(),
    long_description_content_type="text/markdown",
    url="",
    author="Koppula Praveen Kumar",
    author_email="koppulapraveen920@gmail.com",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
    ],
    packages=['AON'],
    include_package_data=True,
    install_requires=['os','shutil'],
    entry_points={
        "console_scripts": [
            "AON=AON.man:main",
        ]
    },
)